@@ -23,6 +23,10 @@ class MyDB:
 	def createDB(self):
 		sql_pragma = "PRAGMA foreign_keys = ON;"
 
+		sql_create_alliface  = "CREATE TABLE IF NOT EXISTS 'main'.'alliface' ( "
+		sql_create_alliface += "'id' INTEGER UNIQUE PRIMARY KEY NOT NULL, "
+		sql_create_alliface += "'iface' TEXT NOT NULL);"
+
 		sql_create_type  = "CREATE TABLE IF NOT EXISTS 'main'.'type' ( "
 		sql_create_type += "'id' INTEGER UNIQUE PRIMARY KEY NOT NULL, "
 		sql_create_type += "'iface' TEXT NOT NULL, "
@@ -49,8 +53,11 @@ class MyDB:
 		sql_create_options += "'limit_size_db' TEXT"
 		sql_create_options += ");"
 
-		sql_type_gprs = "INSERT INTO 'main'.'type' (id, iface) VALUES (1, 'gprs0')"
-		sql_type_wlan = "INSERT INTO 'main'.'type' (id, iface) VALUES (2, 'gprs0')"
+		sql_alliface_gprs = "INSERT INTO 'main'.'alliface' (id, iface) VALUES (1, 'gprs0')"
+		sql_alliface_wlan = "INSERT INTO 'main'.'alliface' (id, iface) VALUES (2, 'wlan0')"
+		sql_alliface_usb =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (3, 'usb0')"
+		sql_alliface_pan =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (4, 'pan0')"
+		sql_alliface_eth =  "INSERT INTO 'main'.'alliface' (id, iface) VALUES (5, 'eth0')"
 		try:
 			R = self.cur.execute(sql_pragma)
 		except Exception, E:
@@ -72,16 +79,38 @@ class MyDB:
 		except Exception, E:
 			print "MyDB::createDB(): [%s] %s\n"%(sql_create_traf, E)
 
-		#try:
-		#	R = self.cur.execute(sql_type_gprs)
-		#except Exception, E:
-		#	pass
-		#	#print "MyDB::createDB(): [%s] %s\n"%(sql_type_gprs, E)
-		
 		try:
 			R = self.cur.execute(sql_create_options)
 		except Exception, E:
 			print "MyDB::createDB(): [%s] %s\n"%(sql_create_options, E)
+		
+		#--- alliface ---#
+		try:
+			R = self.cur.execute(sql_create_alliface)
+		except Exception, E:
+			pass
+		try:
+			R = self.cur.execute(sql_alliface_gprs)
+		except Exception, E:
+			pass
+		try:
+			R = self.cur.execute(sql_alliface_wlan)
+		except Exception, E:
+			pass
+		try:
+			R = self.cur.execute(sql_alliface_usb)
+		except Exception, E:
+			pass
+		try:
+			R = self.cur.execute(sql_alliface_pan)
+		except Exception, E:
+			pass
+		try:
+			R = self.cur.execute(sql_alliface_eth)
+		except Exception, E:
+			pass
+		#----------------#
+		
 
 
 	def writeTraff(self, rx, tx, type, time_stamp = 0):
@@ -132,9 +161,11 @@ class MyDB:
 		return retVal
 
 
+	#---- alliface ----#
 	def getIfaceByType(self,type_id):
 		retVal = None
-		sql = "SELECT iface FROM 'main'.'type' WHERE id == %s;"%(type_id)
+		#sql = "SELECT iface FROM 'main'.'type' WHERE id == %s;"%(type_id)
+		sql = "SELECT iface FROM 'main'.'alliface' WHERE id == %s;"%(type_id)
 		try:
 			self.cur.execute(sql)
 			retVal = self.cur.fetchone()[0]
@@ -146,7 +177,8 @@ class MyDB:
 
 	def getTypeByIface(self,iface):
 		retVal = None
-		sql = "SELECT id FROM 'main'.'type' WHERE iface == '%s';"%(iface)
+		#sql = "SELECT id FROM 'main'.'type' WHERE iface == '%s';"%(iface)
+		sql = "SELECT id FROM 'main'.'alliface' WHERE iface == '%s';"%(iface)
 		try:
 			self.cur.execute(sql)
 			retVal = self.cur.fetchone()[0]
@@ -154,6 +186,21 @@ class MyDB:
 			print "MyDB::getTypeByIface(): [%s] %s\n"%(sql, E)
 			retVal = None
 		return retVal
+	
+	#возвращает полный 'список' сетевых интерфейсов
+	def getBuffIface(self):
+		SQL = "SELECT * FROM 'main'.'alliface'"
+		bufReturn = {}
+		try:
+			j = 0
+			for row in self.cur.execute( SQL ):
+				type = row[0]
+				iface = row[1]
+				bufReturn[ type ] = iface
+		except Exception, E:
+			print "MyDB::getBuffIface(): [%s] %s\n"%(SQL, E)
+		return bufReturn
+	#--------#
 
 
 	# возвращает список сессий за указанный период времени и типу трафика
